@@ -4,7 +4,7 @@ kombu.transport.memory
 
 In-memory transport.
 
-:copyright: (c) 2009 - 2010 by Ask Solem.
+:copyright: (c) 2009 - 2011 by Ask Solem.
 :license: BSD, see LICENSE for more details.
 
 """
@@ -17,11 +17,14 @@ class Channel(virtual.Channel):
     queues = {}
     do_restore = False
 
+    def _has_queue(self, queue, **kwargs):
+        return queue in self.queues
+
     def _new_queue(self, queue, **kwargs):
         if queue not in self.queues:
             self.queues[queue] = Queue()
 
-    def _get(self, queue):
+    def _get(self, queue, timeout=None):
         return self.queues[queue].get(block=False)
 
     def _put(self, queue, message, **kwargs):
@@ -38,6 +41,9 @@ class Channel(virtual.Channel):
         self.queues[queue].queue.clear()
         return size
 
+    def after_reply_message_received(self, queue):
+        pass
+
 
 class Transport(virtual.Transport):
     Channel = Channel
