@@ -177,6 +177,10 @@ class Channel(_Channel, base.StdChannel):
     Message = Message
     events = {"basic_return": []}
 
+    def __init__(self, *args, **kwargs):
+        self.no_ack_consumers = set()
+        super(Channel, self).__init__(*args, **kwargs)
+
     def prepare_message(self, message_data, priority=None,
                 content_type=None, content_encoding=None, headers=None,
                 properties=None):
@@ -197,6 +201,16 @@ class Channel(_Channel, base.StdChannel):
         finally:
             self.connection = None
 
+    def basic_consume(self, *args, **kwargs):
+        consumer_tag = super(Channel, self).basic_consume(*args, **kwargs)
+        if kwargs["no_ack"]:
+            self.no_ack_consumers.add(consumer_tag)
+        return consumer_tag
+
+    def basic_cancel(self, consumer_tag, **kwargs):
+        self.no_ack_consumers.discard(consumer_tag)
+        return super(Channel, self).basic_cancel(consumer_tag, **kwargs)
+
 
 class Transport(base.Transport):
     Connection = Connection
@@ -225,16 +239,9 @@ class Transport(base.Transport):
     def establish_connection(self):
         """Establish connection to the AMQP broker."""
         conninfo = self.client
-        if not conninfo.hostname:
-            conninfo.hostname = "localhost"
-        if conninfo.userid is None:
-            conninfo.userid = "guest"
-        if conninfo.password is None:
-            conninfo.password = "guest"
-        if conninfo.login_method is None:
-            conninfo.login_method = "AMQPLAIN"
-        if not conninfo.port:
-            conninfo.port = self.default_port
+        for name, default_value in self.default_connection_params.items():
+            if not getattr(conninfo, name, None):
+                setattr(conninfo, name, default_value)
         conn = self.Connection(host=conninfo.host,
                                userid=conninfo.userid,
                                password=conninfo.password,
@@ -253,3 +260,9 @@ class Transport(base.Transport):
 
     def verify_connection(self, connection):
         return connection.channels is not None
+
+    @property
+    def default_connection_params(self):
+        return {"userid": "guest", "password": "guest",
+                "port": self.default_port,
+                "hostname": "localhost", "login_method": "AMQPLAIN"}
