@@ -359,6 +359,9 @@ class Channel(AbstractChannel, base.StdChannel):
         self._delete(queue)
         self.state.bindings.pop(queue, None)
 
+    def after_reply_message_received(self, queue):
+        self.queue_delete(queue)
+
     def queue_bind(self, queue, exchange, routing_key, arguments=None,
             **kwargs):
         """Bind `queue` to `exchange` with `routing key`."""
@@ -375,7 +378,7 @@ class Channel(AbstractChannel, base.StdChannel):
             self._queue_bind(exchange, *meta)
 
     def list_bindings(self):
-        for exchange in self.state.exchanges:
+        for exchange in self.get_exchanges():
             table = self.get_table(exchange)
             for routing_key, pattern, queue in table:
                 yield queue, exchange, routing_key
@@ -456,6 +459,9 @@ class Channel(AbstractChannel, base.StdChannel):
         """
         self.qos.prefetch_count = prefetch_count
 
+    def get_exchanges(self):
+        return self.state.exchanges.keys()
+
     def get_table(self, exchange):
         """Get table of bindings for `exchange`."""
         return self.state.exchanges[exchange]["table"]
@@ -472,9 +478,8 @@ class Channel(AbstractChannel, base.StdChannel):
 
         """
         try:
-            table = self.get_table(exchange)
-            return self.typeof(exchange).lookup(table, exchange,
-                                                routing_key, default)
+            return self.typeof(exchange).lookup(self.get_table(exchange),
+                                                exchange, routing_key, default)
         except KeyError:
             self._new_queue(default)
             return [default]
@@ -538,6 +543,7 @@ class Channel(AbstractChannel, base.StdChannel):
                 self._cycle = None
             if self.connection is not None:
                 self.connection.close_channel(self)
+        self.exchange_types = None
 
     def encode_body(self, body, encoding=None):
         if encoding:
@@ -622,7 +628,7 @@ class Transport(base.Transport):
 
     def create_channel(self, connection):
         try:
-            channel = self._avail_channels.pop()
+            return self._avail_channels.pop()
         except IndexError:
             channel = self.Channel(connection)
         self.channels.append(channel)
@@ -638,6 +644,9 @@ class Transport(base.Transport):
             channel.connection = None
 
     def establish_connection(self):
+        # creates channel to verify connection.
+        # this channel is then used as the next requested channel.
+        # (returned by ``create_channel``).
         self._avail_channels.append(self.create_channel(self))
         return self     # for drain events
 
